@@ -4,19 +4,13 @@ import sys
 import tempfile
 
 
-def run_command(cmd):
-    print('Running %r:' % (cmd))
-    os.system(cmd)
-    print('------')
-
-
 def run():
     _path = os.getcwd()
     os.chdir(tempfile.gettempdir())
     print('------')
-    print('os.name=%r' % (os.name))
+    print(f'os.name={os.name!r}')
     print('------')
-    print('sys.platform=%r' % (sys.platform))
+    print(f'sys.platform={sys.platform!r}')
     print('------')
     print('sys.version:')
     print(sys.version)
@@ -24,7 +18,7 @@ def run():
     print('sys.prefix:')
     print(sys.prefix)
     print('------')
-    print('sys.path=%r' % (':'.join(sys.path)))
+    print(f"sys.path={':'.join(sys.path)!r}")
     print('------')
 
     try:
@@ -54,8 +48,7 @@ def run():
 
     if has_newnumpy:
         try:
-            print('Found new numpy version %r in %s' %
-                  (numpy.__version__, numpy.__file__))
+            print(f'Found new numpy version {numpy.__version__!r} in {numpy.__file__}')
         except Exception as msg:
             print('error:', msg)
             print('------')
@@ -150,5 +143,7 @@ def run():
             print('error:', msg)
             print('------')
     os.chdir(_path)
+
+
 if __name__ == "__main__":
     run()
